@@ -2,7 +2,10 @@
 IBM Confidential
 OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
-The source code for this program is not published or otherwise divested of its trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
+
+Copyright (c) 2020 Red Hat, Inc.
 */
 
 package handlers
@@ -25,7 +28,9 @@ func LivenessProbe(w http.ResponseWriter, r *http.Request) {
 func ReadinessProbe(w http.ResponseWriter, r *http.Request) {
 	glog.V(2).Info("readinessProbe - Checking Redis connection.")
 
-	conn, err := db.Pool.Dial() // Go straight to the pool's Dial because we don't actually want to play by the pool's rules here - just want a connection unrelated to all the other ones
+	// Go straight to the pool's Dial because we don't actually want to play by the pool's
+	// rules here - just want a connection unrelated to all the other ones,
+	conn, err := db.Pool.Dial()
 	if err != nil {
 		// Respond with error.
 		glog.Warning("Unable to reach Redis.")
