@@ -4,13 +4,15 @@ OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
 The source code for this program is not published or otherwise divested of its trade secrets,
 irrespective of what has been deposited with the U.S. Copyright Office.
+
+Copyright (c) 2020 Red Hat, Inc.
 */
-// Copyright (c) 2020 Red Hat, Inc.
 
 package handlers
 
 import (
 	"fmt"
+	"reflect"
 	"strconv"
 	"time"
 
@@ -19,6 +21,10 @@ import (
 	rg2 "github.com/redislabs/redisgraph-go"
 )
 
+func getEdgeUID(sourceUID string, edgeType string, destUID string) string {
+	return fmt.Sprintf("%s-%s->%s", sourceUID, edgeType, destUID)
+}
+
 func resyncCluster(clusterName string, resources []*db.Resource, edges []db.Edge, metrics *SyncMetrics) (stats SyncResponse, err error) {
 	glog.Info("Resync for cluster: ", clusterName, " edges to insert: ", len(edges))
 
@@ -53,7 +59,8 @@ func resyncCluster(clusterName string, resources []*db.Resource, edges []db.Edge
 
 	// Delete duplicated records. We have to delete all records with the duplicated UID and recreate.
 	if len(duplicatedResources) > 0 {
-		glog.Warningf("RedisGraph contains duplicate records for some UIDs in cluster %s. Total uids duplicates: %d", clusterName, len(duplicatedResources))
+		glog.Warningf("RedisGraph contains duplicate records for some UIDs in cluster %s. Total uids duplicates: %d",
+			clusterName, len(duplicatedResources))
 		for dupeUID, dupeCount := range duplicatedResources {
 			_, delError := db.Store.Query(db.SanitizeQuery("MATCH (n {_uid:'%s'}) DELETE n", dupeUID))
 			if delError != nil {
@@ -82,17 +89,25 @@ func resyncCluster(clusterName string, resources []*db.Resource, edges []db.Edge
 				resourcesToUpdate = append(resourcesToUpdate, newResource)
 			} else {
 				for key, value := range newEncodedProperties {
-					// Need to compare everything as strings because that's what we get from RedisGraph.
-					stringValue := valueToString(value)
-					existingProperty := valueToString(existingResource.Properties[key])
-
-					if existingProperty != stringValue {
+					var isInterface bool
+					var existingProperty, stringValue string
+					_, interfaceTypeTrue := value.([]interface{})
+					existingInterface, existingInterfaceTypeTrue := existingResource.Properties[key].([]interface{})
+					if interfaceTypeTrue && existingInterfaceTypeTrue {
+						isInterface = true
+					} else {
+						// Need to compare everything other than interfaces as strings because that's what we get from RedisGraph.
+						stringValue = valueToString(value)
+						existingProperty = valueToString(existingResource.Properties[key])
+					}
+					if (isInterface && !reflect.DeepEqual(newResource.Properties[key], existingInterface)) || existingProperty != stringValue {
 						resourcesToUpdate = append(resourcesToUpdate, newResource)
 						break
 					}
 				}
 			}
-			// Remove the resource because it has been proccessed. Any resources remaining when we are done will need to be deleted.
+			// Remove the resource because it has been proccessed.
+			// Any resources remaining when we are done will need to be deleted.
 			delete(existingResources, newResource.UID)
 		}
 	}
@@ -155,9 +170,14 @@ func resyncCluster(clusterName string, resources []*db.Resource, edges []db.Edge
 	if edgesError == nil { //to avoid panic if there is an error executing query
 		for currEdges.Next() {
 			e := currEdges.Record()
-			key := fmt.Sprintf("%s-%s->%s", valueToString(e.GetByIndex(0)), valueToString(e.GetByIndex(1)), valueToString(e.GetByIndex(2)))
+			key := getEdgeUID(valueToString(e.GetByIndex(0)), valueToString(e.GetByIndex(1)),
+				valueToString(e.GetByIndex(2)))
 			if _, ok := existingEdges[key]; !ok {
-				existingEdges[key] = db.Edge{SourceUID: valueToString(e.GetByIndex(0)), EdgeType: valueToString(e.GetByIndex(1)), DestUID: valueToString(e.GetByIndex(2))}
+				existingEdges[key] = db.Edge{
+					SourceUID: valueToString(e.GetByIndex(0)),
+					EdgeType:  valueToString(e.GetByIndex(1)),
+					DestUID:   valueToString(e.GetByIndex(2)),
+				}
 			} else {
 				dupCount++
 			}
@@ -185,9 +205,9 @@ func resyncCluster(clusterName string, resources []*db.Resource, edges []db.Edge
 
 	//Loop through incoming new edges and decide if each edge needs to be added.
 	for _, e := range edges {
-		verifyEdges[fmt.Sprintf("%s-%s->%s", e.SourceUID, e.EdgeType, e.DestUID)] = true
-		if _, exists := existingEdges[fmt.Sprintf("%s-%s->%s", e.SourceUID, e.EdgeType, e.DestUID)]; exists {
-			delete(existingEdges, fmt.Sprintf("%s-%s->%s", e.SourceUID, e.EdgeType, e.DestUID))
+		verifyEdges[getEdgeUID(e.SourceUID, e.EdgeType, e.DestUID)] = true
+		if _, exists := existingEdges[getEdgeUID(e.SourceUID, e.EdgeType, e.DestUID)]; exists {
+			delete(existingEdges, getEdgeUID(e.SourceUID, e.EdgeType, e.DestUID))
 		} else {
 			edgesToAdd = append(edgesToAdd, e)
 		}
@@ -204,7 +224,8 @@ func resyncCluster(clusterName string, resources []*db.Resource, edges []db.Edge
 
 	expectedEdgesAfterProcessing := existingEdgesMapLength + len(edgesToAdd) - len(edgesToDelete)
 	if expectedEdgesAfterProcessing != len(edges) {
-		glog.Warning("For cluster ", clusterName, " expectedEdgesAfterProcessing: ", expectedEdgesAfterProcessing, " doesn't match received len(edges): ", len(edges))
+		glog.Warningf("For cluster %s expectedEdgesAfterProcessing [%d] doesn't match received len(edges) [%d]",
+			clusterName, expectedEdgesAfterProcessing, len(edges))
 	}
 	// INSERT Edges
 	glog.V(4).Info("Resync for cluster ", clusterName, ": Number of edges to insert: ", len(edgesToAdd))
@@ -221,9 +242,11 @@ func resyncCluster(clusterName string, resources []*db.Resource, edges []db.Edge
 		glog.V(4).Info("Edge add errors: ", len(insertEdgeResponse.ResourceErrors))
 		glog.V(4).Info("Edge add errors: ", insertEdgeResponse.ResourceErrors)
 		currEdgesCount = computeIntraEdges(clusterName)
-		glog.V(4).Info("Number of intra edges for cluster ", clusterName, " after adding edges: ", currEdgesCount)
+		glog.V(4).Infof("Number of intra edges for cluster %s after adding edges: %d",
+			clusterName, currEdgesCount)
 		glog.V(4).Info("currEdgesCount: ", currEdgesCount, " incoming edges: ", len(edges))
-		glog.V(4).Info("Added edge count ", insertEdgeResponse.EdgesAdded, " didn't match expected number: ", len(edgesToAdd))
+		glog.V(4).Infof("Added edge count %d didn't match expected number: %d",
+			insertEdgeResponse.EdgesAdded, len(edgesToAdd))
 	}
 
 	// DELETE Edges
@@ -243,7 +266,8 @@ func resyncCluster(clusterName string, resources []*db.Resource, edges []db.Edge
 		currEdgesCount = computeIntraEdges(clusterName)
 		glog.V(4).Info("Number of intra edges for cluster ", clusterName, " after deleting edges: ", currEdgesCount)
 		glog.V(4).Info("currEdgesCount: ", currEdgesCount, " incoming edges: ", len(edges))
-		glog.V(4).Info("Deleted edge count ", deleteEdgeResponse.EdgesDeleted, " didn't match expected number: ", len(edgesToDelete))
+		glog.V(4).Infof("Deleted edge count %d didn't match expected number: %d",
+			deleteEdgeResponse.EdgesDeleted, len(edgesToDelete))
 	}
 
 	// There's no need to UPDATE edges because edges don't have properties yet.
